@@ -12,7 +12,7 @@ from rdr import *
 import rdr.commands.browse      as browse
 import rdr.commands.cluster     as cluster
 import rdr.commands.concordance as concordance
-import rdr.commands.datasette   as datasette
+import rdr.commands.sql   as sql
 import rdr.commands.download    as download
 import rdr.commands.get         as get
 import rdr.commands.grammars    as grammars
@@ -20,6 +20,7 @@ import rdr.commands.catalog     as catalog
 import rdr.commands.ngrams      as ngrams
 import rdr.commands.play        as play
 import rdr.commands.read        as read
+import rdr.commands.edit         as edit
 import rdr.commands.set         as set
 import rdr.commands.tm          as tm
 
@@ -31,9 +32,10 @@ def rdr() : pass
 rdr.add_command( browse.browse )
 rdr.add_command( cluster.cluster )
 rdr.add_command( concordance.concordance )
-rdr.add_command( datasette.datasette )
+rdr.add_command( sql.sql )
 rdr.add_command( download.download )
 rdr.add_command( get.get )
+rdr.add_command( edit.edit )
 rdr.add_command( grammars.grammars )
 rdr.add_command( catalog.catalog )
 rdr.add_command( ngrams.ngrams )
